@@ -37,14 +37,16 @@ Html <- R6::R6Class("Html",
             name='',
             title='',
             visible=TRUE,
-            clearWith='*') {
+            clearWith='*',
+            refs=character()) {
 
             super$initialize(
                 options=options,
                 name=name,
                 title=title,
                 visible=visible,
-                clearWith=clearWith)
+                clearWith=clearWith,
+                refs=refs)
         },
         setContent=function(value) {
 
